//	yf Net mode
//		2005.10.04 - 2005.10.16 Yoshiaki.Ueda
#include "wx/wx.h"
#include "yfNetMode.h"
#include "yfNetList.h"
#include "yfNetListReaders1.h"
#include "yfNetListWriterBase.h"

static const struct Mode {
	unsigned	m_mode;
	wxString	m_name;
	wxString	m_readerClass;
	wxString	m_writerClass;
	wxString	m_wildcard;
} table[]=
{
	{ yfNetMode::Bsch, wxT("Telesis"),
		wxT("yfNetBschReader"), wxT("yfNetBschWriter"),
		wxT("Telesis (*.net *.lst *.txt)|*.net;*.lst;*.txt|")	},
	{ yfNetMode::PADS, wxT("PADS"),
		wxT("yfNetPadsReader"), wxT("yfNetPadsWriter"),
		wxT("PADS (*.net *.lst *.txt)|*.net;*.lst;*.txt|")	},
	{ yfNetMode::ZukenECF, wxT("ZukenECF"),
		wxT("yfNetECFReader"), wxT("yfNetECFWriter"),
		wxT("ZukenECF (*.ccf *.ecf *.net *.lst *.txt)|*.ccf;*.ecf;*.net;*.lst;*.txt|")	},
	{ yfNetMode::Protel, wxT("Protel"),
		wxT("yfNetProtelReader"), wxT("yfNetProtelWriter"),
		wxT("Protel (*.net *.lst *.txt)|*.net;*.lst;*.txt|")	},
};
#define N_MODE	( sizeof table/sizeof table[0] )

void yfNetMode::InitChoice(wxChoice& choice)
{
	for(unsigned i=0; i<N_MODE; i++){
		choice.Append(table[i].m_name);
	}
	choice.SetSelection(0);
}

const wxString yfNetMode::GetDialogWildcard()
{
	wxString wc;
	for(unsigned i=0; i<N_MODE; i++){
		wc.Append(wxString::Format(wxT("%s|*.*|"),table[i].m_name.GetData()));
		//??//wc.Append(table[i].m_wildcard);
	}
	wc.RemoveLast();
	return wc;
}

yfNetListReader* yfNetMode::GetReader(unsigned mode)
{
	for(unsigned i=0; i<N_MODE; i++){
		if(mode==table[i].m_mode){
			return wxDynamicCast(
				wxCreateDynamicObject(table[i].m_readerClass),
				yfNetListReader );
		}
	}
	return NULL;
}

yfNetListWriter* yfNetMode::GetWriter(unsigned mode)
{
	for(unsigned i=0; i<N_MODE; i++){
		if(mode==table[i].m_mode){
			return wxDynamicCast(
				wxCreateDynamicObject(table[i].m_writerClass),
				yfNetListWriter );
		}
	}
	return NULL;
}

int yfNetMode::GetMode(unsigned index)
{
	if(index>=N_MODE) return -1;
	return table[index].m_mode;
}
